@@ -8,9 +8,8 @@
 #include <xsimd/xsimd.hpp>
 
 // Inject some extra symbol in xsimd namespace, until that's fixed upstream
-#if XSIMD_VERSION_MAJOR < 8 ||                                                 \
-    (XSIMD_VERSION_MAJOR == 8 && XSIMD_VERSION_MINOR == 0 &&                   \
-     XSIMD_VERSION_PATCH <= 5)
+#if XSIMD_VERSION_MAJOR < 8 ||                                                                     \
+    (XSIMD_VERSION_MAJOR == 8 && XSIMD_VERSION_MINOR == 0 && XSIMD_VERSION_PATCH <= 5)
 namespace xsimd
 {
   using std::conj;
@@ -29,8 +28,7 @@ namespace numpy
       return std::conj(v);
     }
     template <class T, class A>
-    xsimd::batch<std::complex<T>, A>
-    conjugate(xsimd::batch<std::complex<T>, A> const &v)
+    xsimd::batch<std::complex<T>, A> conjugate(xsimd::batch<std::complex<T>, A> const &v)
     {
       return xsimd::conj(v);
     }
